.. _spkg_sagemath_brial:

=======================================================================================
sagemath_brial: Boolean Ring Algebra with BRiAl
=======================================================================================


This pip-installable source distribution ``passagemath-brial`` provides
a Boolean Ring Algebra implementation using binary decision diagrams,
implemented by the BRiAl library, the successor to PolyBoRi.


Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_brial`
- :ref:`spkg_cython`
- :ref:`spkg_iml`
- :ref:`spkg_linbox`
- :ref:`spkg_m4ri`
- :ref:`spkg_m4rie`
- :ref:`spkg_memory_allocator`
- :ref:`spkg_pkgconfig`
- :ref:`spkg_sage_setup`
- :ref:`spkg_sagemath_categories`
- :ref:`spkg_sagemath_environment`
- :ref:`spkg_sagemath_flint`
- :ref:`spkg_sagemath_modules`
- :ref:`spkg_sagemath_pari`

Version Information
-------------------

package-version.txt::

    10.6.4

version_requirements.txt::

    passagemath-brial ~= 10.6.4.0

Equivalent System Packages
--------------------------

(none known)
